@@ -9,6 +9,7 @@ module can change at any time without warning.
 from __future__ import annotations
 
 import copy
+import itertools
 import warnings
 from collections import namedtuple
 from typing import Any, Dict, List, Optional, Protocol, Tuple, Union, cast
@@ -467,7 +468,7 @@ def normalize(coords: List[XY]) -> List[XY]:
 def segment(coords: List[XY]) -> List[List[XY]]:
     segment = []
     segments = []
-    for start, end in zip(coords, coords[1:]):
+    for start, end in itertools.pairwise(coords):
         segment.append(start)
         if (end[0] - start[0] > 180) and (end[0] - start[0] != 360):  # left
             latitude = crossing_latitude(start, end)
@@ -662,7 +663,9 @@ def is_self_closing(segment: List[XY]) -> bool:
     )
 
 
-def bbox(shape: Dict[str, Any] | GeoInterface) -> List[float]:
+def bbox(
+    shape: Dict[str, Any] | GeoInterface, force_over_antimeridian: bool = False
+) -> List[float]:
     """Calculates a GeoJSON-spec conforming bounding box for a shape.
 
     Per `the GeoJSON spec
@@ -672,6 +675,7 @@ def bbox(shape: Dict[str, Any] | GeoInterface) -> List[float]:
 
     Args:
         shape: The polygon or multipolygon for which to calculate the bounding box.
+        force_over_antimeridan: Force the bounding box to be over the antimeridian.
 
     Returns:
         List[float]: The bounding box.
@@ -696,7 +700,7 @@ def bbox(shape: Dict[str, Any] | GeoInterface) -> List[float]:
             if is_coincident_to_antimeridian(polygon):
                 crosses_antimeridian = True
 
-        if crosses_antimeridian:
+        if crosses_antimeridian or force_over_antimeridian:
             return [max(xmins), ymin, min(xmaxs), ymax]
         else:
             return [min(xmins), ymin, max(xmaxs), ymax]
